@@ -194,7 +194,7 @@ class Feature:
         >>> import audb
         >>> db = audb.load(
         ...     'emodb',
-        ...     version='1.2.0',
+        ...     version='1.3.0',
         ...     media='wav/03a01Fa.wav',
         ...     full_path=False,
         ...     verbose=False,
@@ -204,6 +204,10 @@ class Feature:
                                                            mean       std
         file            start  end
         wav/03a01Fa.wav 0 days 0 days 00:00:01.898250 -0.000311  0.082317
+        >>> interface.process_index(index, root=db.root, preserve_index=True)
+                        mean       std
+        file
+        wav/03a01Fa.wav -0.000311  0.082317
         >>> # Apply interface with a sliding window
         >>> interface = Feature(
         ...     ['mean', 'std'],
@@ -324,16 +328,6 @@ class Feature:
                     dtype=object,
                 )
 
-        process_func_args = process_func_args or {}
-        if kwargs:
-            warnings.warn(
-                utils.kwargs_deprecation_warning,
-                category=UserWarning,
-                stacklevel=2,
-            )
-            for key, value in kwargs.items():
-                process_func_args[key] = value
-
         if win_dur is None and hop_dur is not None:
             raise ValueError(
                 "You have to specify 'win_dur' if 'hop_dur' is given."
@@ -343,6 +337,7 @@ class Feature:
 
         # add 'win_dur' and 'hop_dur' to process_func_args
         # if expected by function but not yet set
+        process_func_args = process_func_args or {}
         signature = inspect.signature(process_func)
         if (
             'win_dur' in signature.parameters
@@ -520,6 +515,7 @@ class Feature:
             self,
             index: pd.Index,
             *,
+            preserve_index: bool = False,
             root: str = None,
             cache_root: str = None,
     ) -> pd.DataFrame:
@@ -537,6 +533,12 @@ class Feature:
 
         Args:
             index: index with segment information
+            preserve_index: if ``True``
+                and :attr:`audinterface.Feature.process.segment` is ``None``
+                the returned index
+                will be of same type
+                as the original one,
+                otherwise always a segmented index is returned
             root: root folder to expand relative file paths
             cache_root: cache folder (see description)
 
@@ -567,6 +569,11 @@ class Feature:
             if cache_path is not None:
                 df.to_pickle(cache_path, protocol=4)
 
+        if self.process.segment is None and preserve_index:
+            # Convert segmented index to filewise index
+            # if original index was filewise
+            df.index = index
+
         return df
 
     def process_signal(
@@ -751,36 +758,97 @@ class Feature:
 
     def _series_to_frame(
             self,
-            series: pd.Series,
+            y: pd.Series,
     ) -> pd.DataFrame:
 
-        if series.empty:
+        if y.empty:
             return pd.DataFrame(
                 columns=self.column_names,
                 dtype=object,
             )
 
-        frames = [None] * len(series)
-        if len(series.index.levels) == 3:
-            for idx, ((file, start, end), values) in enumerate(series.items()):
-                frames[idx] = self._values_to_frame(
-                    values, file=file, start=start, end=end,
-                )
+        num = len(y)
+
+        if (
+                self.win_dur is not None and
+                self.process_func_applies_sliding_window
+        ):
+
+            win_dur = utils.to_timedelta(
+                self.win_dur,
+                self.process.sampling_rate,
+            )
+            hop_dur = utils.to_timedelta(
+                self.hop_dur,
+                self.process.sampling_rate,
+            )
+
+            starts = []
+            ends = []
+            data = []
+
+            if len(y.index.levels) == 3:
+
+                files = []
+
+                for idx, ((file, start, end), values) in enumerate(y.items()):
+
+                    frames = self._values_to_frame(values)
+                    data.append(frames)
+
+                    times = pd.timedelta_range(
+                        start,
+                        freq=hop_dur,
+                        periods=frames.shape[0],
+                    )
+
+                    starts.extend(times.to_list())
+                    ends.extend((times + win_dur).to_list())
+                    files.extend([file] * len(times))
+
+                index = audformat.segmented_index(files, starts, ends)
+
+            else:
+
+                for idx, ((start, end), values) in enumerate(y.items()):
+                    frames = self._values_to_frame(values)
+                    data.append(frames)
+
+                    times = pd.timedelta_range(
+                        start,
+                        freq=hop_dur,
+                        periods=frames.shape[0],
+                    )
+
+                    starts.extend(times.to_list())
+                    ends.extend((times + win_dur).to_list())
+
+                index = utils.signal_index(starts, ends)
+
+            data = np.concatenate(data)
+
         else:
-            for idx, ((start, end), values) in enumerate(series.items()):
-                frames[idx] = self._values_to_frame(
-                    values, start=start, end=end,
-                )
-        return pd.concat(frames, axis='index')
+
+            index = y.index
+            dtype = self._values_to_frame(y[0]).dtype
+            shape = (num, len(self.column_names))
+            data = np.empty(shape, dtype)
+
+            for idx, values in enumerate(y):
+                data[idx, :] = self._values_to_frame(values)
+
+        df = pd.DataFrame(
+            data,
+            index=index,
+            columns=self.column_names,
+        )
+
+        return df
 
     def _values_to_frame(
             self,
             features: np.ndarray,
-            start: pd.Timedelta,
-            end: pd.Timedelta,
-            *,
-            file: str = None,
-    ) -> pd.DataFrame:
+    ) -> np.ndarray:
 
         # Convert features to a pd.DataFrame
         # Assumed formats are:
@@ -789,12 +857,6 @@ class Feature:
         # [n_features, n_frames]
         # [n_features]
 
-        win_dur = self.win_dur
-        hop_dur = self.hop_dur
-        if win_dur is not None:
-            win_dur = utils.to_timedelta(win_dur, self.process.sampling_rate)
-            hop_dur = utils.to_timedelta(hop_dur, self.process.sampling_rate)
-
         features = self._reshape_3d(features)
         n_channels, n_features, n_frames = features.shape
 
@@ -803,31 +865,14 @@ class Feature:
         new_shape = (n_channels * n_features, n_frames)
         features = features.reshape(new_shape).T
 
-        if n_frames > 1 and win_dur is None:
+        if n_frames > 1 and self.win_dur is None:
             raise RuntimeError(
                 f"Got "
                 f"{n_frames} "
                 f"frames, but 'win_dur' is not set."
             )
 
-        if win_dur is not None:
-            starts = pd.timedelta_range(
-                start,
-                freq=hop_dur,
-                periods=n_frames,
-            )
-            ends = starts + win_dur
-        else:
-            starts = [start]
-            ends = [end]
-
-        if file is None:
-            index = utils.signal_index(starts, ends)
-        else:
-            files = [file] * len(starts)
-            index = audformat.segmented_index(files, starts, ends)
-
-        return pd.DataFrame(features, index, columns=self.column_names)
+        return features
 
     def __call__(
             self,
