@@ -1,8 +1,8 @@
 import errno
 import inspect
+import itertools
 import os
 import typing
-import warnings
 
 import numpy as np
 import pandas as pd
@@ -106,7 +106,7 @@ class Process:
         >>> import audb
         >>> db = audb.load(
         ...     'emodb',
-        ...     version='1.2.0',
+        ...     version='1.3.0',
         ...     media='wav/03a01Fa.wav',
         ...     full_path=False,
         ...     verbose=False,
@@ -116,6 +116,10 @@ class Process:
         file             start   end
         wav/03a01Fa.wav  0 days  0 days 00:00:01.898250    -0.000311
         dtype: float32
+        >>> interface.process_index(index, root=db.root, preserve_index=True)
+        file
+        wav/03a01Fa.wav  -0.000311
+        dtype: float32
         >>> # Apply interface with a sliding window
         >>> interface = Process(
         ...     process_func=mean,
@@ -148,7 +152,6 @@ class Process:
             num_workers: typing.Optional[int] = 1,
             multiprocessing: bool = False,
             verbose: bool = False,
-            **kwargs,
     ):
         if channels is not None:
             channels = audeer.to_list(channels)
@@ -157,16 +160,6 @@ class Process:
             def process_func(signal, _):
                 return signal
 
-        process_func_args = process_func_args or {}
-        if kwargs:
-            warnings.warn(
-                utils.kwargs_deprecation_warning,
-                category=UserWarning,
-                stacklevel=2,
-            )
-            for key, value in kwargs.items():
-                process_func_args[key] = value
-
         if resample and sampling_rate is None:
             raise ValueError(
                 'sampling_rate has to be provided for resample = True.'
@@ -182,6 +175,7 @@ class Process:
         # figure out if special arguments
         # to pass to the processing function
         signature = inspect.signature(process_func)
+        process_func_args = process_func_args or {}
         self._process_func_special_args = {
             'idx': False,
             'root': False,
@@ -250,10 +244,17 @@ class Process:
             root: str = None,
             start: pd.Timedelta = None,
             end: pd.Timedelta = None,
-    ) -> pd.Series:
+    ) -> typing.Tuple[
+        typing.List[typing.Any],
+        typing.List[str],
+        typing.List[pd.Timedelta],
+        typing.List[pd.Timedelta],
+    ]:
 
-        start = utils.to_timedelta(start, self.sampling_rate)
-        end = utils.to_timedelta(end, self.sampling_rate)
+        if start is not None:
+            start = utils.to_timedelta(start, self.sampling_rate)
+        if end is not None:
+            end = utils.to_timedelta(end, self.sampling_rate)
 
         signal, sampling_rate = utils.read_audio(
             file,
@@ -261,7 +262,8 @@ class Process:
             end=end,
             root=root,
         )
-        y = self._process_signal(
+
+        y, files, starts, ends = self._process_signal(
             signal,
             sampling_rate,
             idx=idx,
@@ -270,28 +272,17 @@ class Process:
         )
 
         if self.win_dur is not None:
-
             if start is not None:
-                starts = y.index.levels[1] + start
-                ends = y.index.levels[2] + start
-                y.index = y.index.set_levels(
-                    [starts, ends],
-                    level=[1, 2],
-                )
-
+                starts = starts + start
+                ends = ends + start
         else:
+            if start is not None and not pd.isna(start):
+                starts[0] += start
+                ends[0] += start
+            if self.keep_nat and (end is None or pd.isna(end)):
+                ends[0] = pd.NaT
 
-            if start is None or pd.isna(start):
-                start = y.index.levels[1][0]
-            if end is None or (pd.isna(end) and not self.keep_nat):
-                end = y.index.levels[2][0] + start
-
-            y.index = y.index.set_levels(
-                [[start], [end]],
-                level=[1, 2],
-            )
-
-        return y
+        return y, files, starts, ends
 
     def process_file(
             self,
@@ -332,13 +323,21 @@ class Process:
             )
             return self._process_index_wo_segment(index, root)
         else:
-            return self._process_file(
+
+            y, files, starts, ends = self._process_file(
                 file,
                 root=root,
                 start=start,
                 end=end,
             )
 
+            index = audformat.segmented_index(files, starts, ends)
+
+            if len(y) == 0:
+                return pd.Series([], index, dtype=object)
+            else:
+                return pd.Series(y, index)
+
     def process_files(
             self,
             files: typing.Sequence[str],
@@ -396,7 +395,7 @@ class Process:
 
         verbose = self.verbose
         self.verbose = False  # avoid nested progress bar
-        y = audeer.run_tasks(
+        xs = audeer.run_tasks(
             self._process_file,
             params,
             num_workers=self.num_workers,
@@ -405,7 +404,16 @@ class Process:
             task_description=f'Process {len(files)} files',
         )
         self.verbose = verbose
-        return pd.concat(y)
+
+        y = list(itertools.chain.from_iterable([x[0] for x in xs]))
+        files = list(itertools.chain.from_iterable([x[1] for x in xs]))
+        starts = list(itertools.chain.from_iterable([x[2] for x in xs]))
+        ends = list(itertools.chain.from_iterable([x[3] for x in xs]))
+
+        index = audformat.segmented_index(files, starts, ends)
+        y = pd.Series(y, index)
+
+        return y
 
     def process_folder(
             self,
@@ -466,7 +474,7 @@ class Process:
             for idx, (file, start, end) in enumerate(index)
         ]
 
-        y = audeer.run_tasks(
+        xs = audeer.run_tasks(
             self._process_file,
             params,
             num_workers=self.num_workers,
@@ -475,12 +483,21 @@ class Process:
             task_description=f'Process {len(index)} segments',
         )
 
-        return pd.concat(y)
+        y = list(itertools.chain.from_iterable([x[0] for x in xs]))
+        files = list(itertools.chain.from_iterable([x[1] for x in xs]))
+        starts = list(itertools.chain.from_iterable([x[2] for x in xs]))
+        ends = list(itertools.chain.from_iterable([x[3] for x in xs]))
+
+        index = audformat.segmented_index(files, starts, ends)
+        y = pd.Series(y, index)
+
+        return y
 
     def process_index(
             self,
             index: pd.Index,
             *,
+            preserve_index: bool = False,
             root: str = None,
             cache_root: str = None,
     ) -> pd.Series:
@@ -496,6 +513,12 @@ class Process:
 
         Args:
             index: index with segment information
+            preserve_index: if ``True``
+                and :attr:`audinterface.Process.segment` is ``None``
+                the returned index
+                will be of same type
+                as the original one,
+                otherwise always a segmented index is returned
             root: root folder to expand relative file paths
             cache_root: cache folder (see description)
 
@@ -519,16 +542,24 @@ class Process:
         if cache_path and os.path.exists(cache_path):
             y = pd.read_pickle(cache_path)
         else:
-            index = audformat.utils.to_segmented_index(index)
+            segmented_index = audformat.utils.to_segmented_index(index)
 
             if self.segment is not None:
-                index = self.segment.process_index(index, root=root)
+                segmented_index = self.segment.process_index(
+                    segmented_index,
+                    root=root,
+                )
 
-            y = self._process_index_wo_segment(index, root)
+            y = self._process_index_wo_segment(segmented_index, root)
 
             if cache_path is not None:
                 y.to_pickle(cache_path, protocol=4)
 
+        if self.segment is None and preserve_index:
+            # Convert segmented index to filewise index
+            # if original index was filewise
+            y.index = index
+
         return y
 
     def _process_signal(
@@ -541,7 +572,12 @@ class Process:
             file: str = None,
             start: pd.Timedelta = None,
             end: pd.Timedelta = None,
-    ) -> pd.Series:
+    ) -> typing.Tuple[
+        typing.List[typing.Any],
+        typing.List[str],
+        typing.List[pd.Timedelta],
+        typing.List[pd.Timedelta],
+    ]:
 
         signal = np.atleast_2d(signal)
 
@@ -607,16 +643,7 @@ class Process:
             ends = [end]
             y = [y]
 
-        if file is not None:
-            files = [file] * len(starts)
-            index = audformat.segmented_index(files, starts, ends)
-        else:
-            index = utils.signal_index(starts, ends)
-
-        if len(y) == 0:
-            return pd.Series([], index, dtype=object)
-        else:
-            return pd.Series(y, index)
+        return y, [file] * len(starts), starts, ends
 
     def process_signal(
             self,
@@ -626,7 +653,7 @@ class Process:
             file: str = None,
             start: Timestamp = None,
             end: Timestamp = None,
-    ) -> typing.Any:
+    ) -> pd.Series:
         r"""Process audio signal and return result.
 
         .. note:: If a ``file`` is given, the index of the returned frame
@@ -668,9 +695,12 @@ class Process:
                 index,
             )
         else:
-            start = utils.to_timedelta(start, sampling_rate)
-            end = utils.to_timedelta(end, sampling_rate)
-            return self._process_signal(
+            if start is not None:
+                start = utils.to_timedelta(start, sampling_rate)
+            if end is not None:
+                end = utils.to_timedelta(end, sampling_rate)
+
+            y, files, starts, ends = self._process_signal(
                 signal,
                 sampling_rate,
                 file=file,
@@ -678,6 +708,16 @@ class Process:
                 end=end,
             )
 
+            if file is not None:
+                index = audformat.segmented_index(files, starts, ends)
+            else:
+                index = utils.signal_index(starts, ends)
+
+            if len(y) == 0:
+                return pd.Series([], index, dtype=object)
+            else:
+                return pd.Series(y, index)
+
     def _process_signal_from_index_wo_segment(
             self,
             signal: np.ndarray,
@@ -689,7 +729,12 @@ class Process:
         if index.empty:
             return pd.Series(None, index=index, dtype=object)
 
-        if isinstance(index, pd.MultiIndex) and len(index.levels) == 2:
+        skip_file_level = (
+                isinstance(index, pd.MultiIndex) and
+                len(index.levels) == 2
+        )
+
+        if skip_file_level:
             params = [
                 (
                     (signal, sampling_rate),
@@ -714,7 +759,7 @@ class Process:
                 ) for idx, (file, start, end) in enumerate(index)
             ]
 
-        y = audeer.run_tasks(
+        xs = audeer.run_tasks(
             self._process_signal,
             params,
             num_workers=self.num_workers,
@@ -723,7 +768,19 @@ class Process:
             task_description=f'Process {len(index)} segments',
         )
 
-        return pd.concat(y)
+        y = list(itertools.chain.from_iterable([x[0] for x in xs]))
+        starts = list(itertools.chain.from_iterable([x[2] for x in xs]))
+        ends = list(itertools.chain.from_iterable([x[3] for x in xs]))
+
+        if skip_file_level:
+            index = utils.signal_index(starts, ends)
+        else:
+            files = list(itertools.chain.from_iterable([x[1] for x in xs]))
+            index = audformat.segmented_index(files, starts, ends)
+
+        y = pd.Series(y, index)
+
+        return y
 
     def process_signal_from_index(
             self,
@@ -840,7 +897,7 @@ class Process:
         r"""Apply processing to signal.
 
         This function processes the signal **without** transforming the output
-        into a :class:`pd.Series`. Instead it will return the raw processed
+        into a :class:`pd.Series`. Instead, it will return the raw processed
         signal. However, if channel selection, mixdown and/or resampling
         is enabled, the signal will be first remixed and resampled if the
         input sampling rate does not fit the expected sampling rate.
