@@ -1,5 +1,6 @@
 import os
 
+import audiofile
 import numpy as np
 import pandas as pd
 import pytest
@@ -429,16 +430,10 @@ def test_process_func_args():
             'arg2': 'bar',
         }
     )
-    with pytest.warns(UserWarning):
-        audinterface.Feature(
-            feature_names=('o1', 'o2', 'o3'),
-            process_func=process_func,
-            arg1='foo',
-            arg2='bar',
-        )
 
 
-def test_process_index(tmpdir):
+@pytest.mark.parametrize('preserve_index', [False, True])
+def test_process_index(tmpdir, preserve_index):
 
     cache_root = os.path.join(tmpdir, 'cache')
 
@@ -451,7 +446,7 @@ def test_process_index(tmpdir):
     # empty
 
     index = audformat.segmented_index()
-    df = feature.process_index(index)
+    df = feature.process_index(index, preserve_index=preserve_index)
     assert df.empty
     pd.testing.assert_index_equal(df.columns, feature.column_names)
 
@@ -465,24 +460,50 @@ def test_process_index(tmpdir):
         af.write(path, SIGNAL_2D, SAMPLING_RATE)
     df_expected = np.ones((2, NUM_CHANNELS * NUM_FEATURES))
 
-    # absolute paths
-    index = audformat.segmented_index(paths, [0, 1], [2, 3])
-    df = feature.process_index(index)
+    # absolute paths segmented index
+    index = audformat.segmented_index(paths, [0, 1], [None, 3])
+    df = feature.process_index(index, preserve_index=preserve_index)
     assert df.index.get_level_values('file')[0] == paths[0]
+    if preserve_index:
+        pd.testing.assert_index_equal(df.index, index)
     np.testing.assert_array_equal(df.values, df_expected)
     pd.testing.assert_index_equal(df.columns, feature.column_names)
-    df = feature.process_index(index)
 
-    # relative paths
-    index = audformat.segmented_index(files, [0, 1], [2, 3])
-    df = feature.process_index(index, root=root)
+    # relative paths segmented index
+    index = audformat.segmented_index(files, [0, 1], [None, 3])
+    df = feature.process_index(index, preserve_index=preserve_index, root=root)
     assert df.index.get_level_values('file')[0] == files[0]
+    if preserve_index:
+        pd.testing.assert_index_equal(df.index, index)
+    np.testing.assert_array_equal(df.values, df_expected)
+    pd.testing.assert_index_equal(df.columns, feature.column_names)
+
+    # absolute paths filewise index
+    index = audformat.filewise_index(paths)
+    df = feature.process_index(index, preserve_index=preserve_index)
+    if preserve_index:
+        assert df.index[0] == paths[0]
+        pd.testing.assert_index_equal(df.index, index)
+    else:
+        assert df.index.get_level_values('file')[0] == paths[0]
+    np.testing.assert_array_equal(df.values, df_expected)
+    pd.testing.assert_index_equal(df.columns, feature.column_names)
+
+    # relative paths filewise index
+    index = audformat.filewise_index(files)
+    df = feature.process_index(index, preserve_index=preserve_index, root=root)
+    if preserve_index:
+        assert df.index[0] == files[0]
+        pd.testing.assert_index_equal(df.index, index)
+    else:
+        assert df.index.get_level_values('file')[0] == files[0]
     np.testing.assert_array_equal(df.values, df_expected)
     pd.testing.assert_index_equal(df.columns, feature.column_names)
 
     # cache result
     df = feature.process_index(
         index,
+        preserve_index=preserve_index,
         root=root,
         cache_root=cache_root,
     )
@@ -492,12 +513,14 @@ def test_process_index(tmpdir):
     with pytest.raises(RuntimeError):
         feature.process_index(
             index,
+            preserve_index=preserve_index,
             root=root,
         )
 
     # loading from cache still works
     df_cached = feature.process_index(
         index,
+        preserve_index=preserve_index,
         root=root,
         cache_root=cache_root,
     )
@@ -939,6 +962,13 @@ def test_process_signal_from_index(index, expected_features):
     np.testing.assert_array_equal(features.values, expected_features)
 
 
+@pytest.mark.parametrize(
+    'signal, num_channels, sampling_rate',
+    [
+        (SIGNAL_1D, 1, SAMPLING_RATE),
+        (SIGNAL_2D, 2, SAMPLING_RATE),
+    ]
+)
 @pytest.mark.parametrize(
     'process_func, is_mono, applies_sliding_window, feature_names',
     [
@@ -962,7 +992,9 @@ def test_process_signal_from_index(index, expected_features):
         (f'{SAMPLING_RATE // 2}', f'{SAMPLING_RATE // 4}'),
     ],
 )
-def test_signal_sliding_window(process_func, is_mono, applies_sliding_window,
+def test_signal_sliding_window(tmpdir, signal, num_channels,
+                               sampling_rate, process_func, is_mono,
+                               applies_sliding_window,
                                feature_names, win_dur, hop_dur):
 
     interface = audinterface.Feature(
@@ -970,39 +1002,55 @@ def test_signal_sliding_window(process_func, is_mono, applies_sliding_window,
         process_func=process_func,
         process_func_is_mono=is_mono,
         process_func_applies_sliding_window=applies_sliding_window,
-        channels=range(NUM_CHANNELS),
+        channels=range(num_channels),
         win_dur=win_dur,
         hop_dur=hop_dur,
-        sampling_rate=SAMPLING_RATE,
+        sampling_rate=sampling_rate,
     )
 
-    for signal in [SIGNAL_1D, SIGNAL_2D]:
+    # signal
 
-        df = interface.process_signal(
-            SIGNAL_2D,
-            SAMPLING_RATE,
-        )
-        n_time_steps = len(df)
+    df = interface.process_signal(
+        signal,
+        sampling_rate,
+    )
+    n_time_steps = len(df)
 
-        win_dur = audinterface.utils.to_timedelta(win_dur, SAMPLING_RATE)
-        if hop_dur is None:
-            hop_dur = win_dur / 2
-        hop_dur = audinterface.utils.to_timedelta(hop_dur, SAMPLING_RATE)
+    win_dur = audinterface.utils.to_timedelta(win_dur, sampling_rate)
+    if hop_dur is None:
+        hop_dur = win_dur / 2
+    hop_dur = audinterface.utils.to_timedelta(hop_dur, sampling_rate)
 
-        starts = pd.timedelta_range(
-            pd.to_timedelta(0),
-            freq=hop_dur,
-            periods=n_time_steps,
-        )
-        ends = starts + win_dur
+    starts = pd.timedelta_range(
+        pd.to_timedelta(0),
+        freq=hop_dur,
+        periods=n_time_steps,
+    )
+    ends = starts + win_dur
 
-        index = audinterface.utils.signal_index(starts, ends)
-        expected = pd.DataFrame(
-            np.ones((n_time_steps, len(interface.column_names))),
-            index=index,
-            columns=interface.column_names,
-        )
-        pd.testing.assert_frame_equal(df, expected)
+    index = audinterface.utils.signal_index(starts, ends)
+    expected = pd.DataFrame(
+        np.ones((n_time_steps, len(interface.column_names))),
+        index=index,
+        columns=interface.column_names,
+    )
+    pd.testing.assert_frame_equal(df, expected)
+
+    # file
+
+    file = audeer.path(tmpdir, 'tmp.wav')
+    audiofile.write(file, signal, sampling_rate, bit_depth=32)
+
+    df = interface.process_file(file)
+
+    index = audformat.segmented_index([file] * len(starts), starts, ends)
+    expected = pd.DataFrame(
+        np.ones((n_time_steps, len(interface.column_names))),
+        index=index,
+        columns=interface.column_names,
+        dtype=np.float32,
+    )
+    pd.testing.assert_frame_equal(df, expected)
 
 
 def test_signal_sliding_window_error():
